.. module:: enaml.scintilla.idle_theme

==========================
enaml.scintilla.idle_theme
==========================

.. rubric:: Data

.. autosummary::
    :nosignatures:

    IDLE_THEME


.. autodata:: IDLE_THEME
